@@ -44,13 +44,13 @@ fn main() {
             move |evt, mut dispatch_data| {
                 let next_action = dispatch_data.get::<Option<WEvent>>().unwrap();
                 // Keep last event in priority order : Close > Configure > Refresh
-                let replace = match (&evt, &*next_action) {
+                let replace = matches!(
+                    (&evt, &*next_action),
                     (_, &None)
-                    | (_, &Some(WEvent::Refresh))
-                    | (&WEvent::Configure { .. }, &Some(WEvent::Configure { .. }))
-                    | (&WEvent::Close, _) => true,
-                    _ => false,
-                };
+                        | (_, &Some(WEvent::Refresh))
+                        | (&WEvent::Configure { .. }, &Some(WEvent::Configure { .. }))
+                        | (&WEvent::Close, _)
+                );
                 if replace {
                     *next_action = Some(evt);
                 }
@@ -128,12 +128,10 @@ fn main() {
                     }
                 }
             }
-        } else {
-            if let Some((kbd, source)) = opt_kbd.take() {
-                // the keyboard has been removed, cleanup
-                kbd.release();
-                loop_handle.remove(source);
-            }
+        } else if let Some((kbd, source)) = opt_kbd.take() {
+            // the keyboard has been removed, cleanup
+            kbd.release();
+            loop_handle.remove(source);
         }
     });
 
@@ -199,6 +197,7 @@ fn print_keyboard_event(event: KbEvent, seat_name: &str) {
     }
 }
 
+#[allow(clippy::many_single_char_names)]
 fn redraw(
     pool: &mut AutoMemPool,
     surface: &wl_surface::WlSurface,
